@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Data::Printer::Filter::DBIx::Class;
-$Data::Printer::Filter::DBIx::Class::VERSION = '0.000002';
+$Data::Printer::Filter::DBIx::Class::VERSION = '0.000003';
 use Data::Printer::Filter;
 use Scalar::Util qw(blessed);
 use Term::ANSIColor;
@@ -13,18 +13,29 @@ filter '-class' => sub {
 
     if ( $obj->isa( 'DBIx::Class::Row' ) ) {
         my %row = $obj->get_columns;
-        return _add_prefix( $obj, $properties, \%row );
+        return _add_prefix( $obj, $properties, [ \%row ] );
     }
 
     if ( $obj->isa( 'DBIx::Class::ResultSet' ) ) {
         my @rows;
+        my $row_limit
+            = defined $ENV{DDP_DBIC_ROW_LIMIT} ? $ENV{DDP_DBIC_ROW_LIMIT} : 5;
+
         while ( defined( my $row = $obj->next ) ) {
 
             # Could be inflating to a HashRef
             push @rows, blessed( $row )
                 && $row->can( 'get_columns' ) ? { $row->get_columns } : $row;
+
+            last if $row_limit && @rows == $row_limit;
         }
-        return _add_prefix( $obj, $properties, @rows );
+        my $msg = 'Showing all results';
+        if ( $row_limit && @rows == $row_limit ) {
+            $msg = sprintf( 'Showing first %i out of %i results.',
+                scalar @rows, $obj->count );
+        }
+
+        return _add_prefix( $obj, $properties, \@rows, $msg );
     }
 
     return;
@@ -33,7 +44,8 @@ filter '-class' => sub {
 sub _add_prefix {
     my $obj        = shift;
     my $properties = shift;
-    my @rows       = @_;
+    my $rows       = shift;
+    my $msg        = shift;
 
     my $str = colored( ref( $obj ), $properties->{color}{class} );
     $str .= ' (' . $obj->result_class . ')' if $obj->can( 'result_class' );
@@ -59,7 +71,8 @@ sub _add_prefix {
     # Remove require once Data::Printer > 0.36 is released
     require Data::Printer;
 
-    return $str . q{ } . Data::Printer::np( @rows );
+    $str .= ' (' . $msg . ')' if $msg;
+    return $str . q{ } . Data::Printer::np( $rows );
 }
 1;
 
@@ -73,7 +86,7 @@ Data::Printer::Filter::DBIx::Class - Apply special Data::Printer filters to DBIx
 
 =head1 VERSION
 
-version 0.000002
+version 0.000003
 
 =head1 SYNOPSIS
 
@@ -90,9 +103,15 @@ or, in your C<.dataprinter> file:
 Huge chunks of this have been lifted directly from L<Data::Printer::Filter::DB>
 This filter differs in that it also adds the values from C<get_columns()> to
 the output.  For a L<DBIx::Class::Row> object, the column values are return in
-the data.  For a L<DBIx::Class::ResultSet>, all of the rows in the ResultSet
-are returned, with the contents of C<get_columns()> included.  If you're
-dealing with huge ResultSets, this may not be what you want.  Caveat emptor.
+the data.  For a L<DBIx::Class::ResultSet>, by default the first 5 rows in the
+ResultSet are returned, with the contents of C<get_columns()> included.  You
+can change this behaviour via C<$ENV{DDP_DBIC_ROW_LIMIT}>.
+
+    # Return up to 1,000 rows per ResultSet
+    $ENV{DDP_DBIC_ROW_LIMIT} = 1000;
+
+    # Return every row from every ResultSet
+    $ENV{DDP_DBIC_ROW_LIMIT} = 0;
 
 =head1 AUTHOR
 
